@@ -3,16 +3,13 @@
 #' Round values to integers and then display as ordinal values (e.g. 1st, 2nd,
 #' 3rd). Built-in rules are provided for English, French, and Spanish.
 #'
-#' @section Old interface:
-#' `ordinal()` and `format_ordinal()` are retired; please use `label_ordinal()`
-#' instead.
-#' @inherit number_format return params
+#' @inherit label_number return params
 #' @param prefix,suffix Symbols to display before and after value.
 #' @param rules Named list of regular expressions, matched in order.
 #'   Name gives suffix, and value specifies which numbers to match.
 #' @param gender Masculin or feminin gender for French ordinal.
 #' @param plural Plural or singular for French ordinal.
-#' @param ... Other arguments passed on to [base::format()].
+#' @inheritDotParams number
 #' @export
 #' @family labels for continuous scales
 #' @examples
@@ -34,7 +31,8 @@
 label_ordinal <- function(prefix = "", suffix = "", big.mark = " ",
                           rules = ordinal_english(), ...) {
   force_all(prefix, suffix, big.mark, rules, ...)
-  function(x) ordinal(
+  function(x) {
+    ordinal(
       x,
       prefix = prefix,
       suffix = suffix,
@@ -42,6 +40,7 @@ label_ordinal <- function(prefix = "", suffix = "", big.mark = " ",
       rules = rules,
       ...
     )
+  }
 }
 
 
@@ -62,7 +61,10 @@ ordinal_english <- function() {
 #' @export
 #' @rdname label_ordinal
 ordinal_french <- function(gender = c("masculin", "feminin"), plural = FALSE) {
-  suffix <- switch(match.arg(gender), masculin = "er", feminin = "re")
+  suffix <- switch(match.arg(gender),
+    masculin = "er",
+    feminin = "re"
+  )
 
   label <- list("^1$", ".")
   names(label) <- c(suffix, "e")
@@ -78,12 +80,21 @@ ordinal_spanish <- function() {
   stats::setNames(list("."), ".\u00ba")
 }
 
+#' Superseded interface to `label_ordinal()`
+#'
+#' @description
+#' `r lifecycle::badge("superseded")`
+#'
+#' These functions are kept for backward compatibility; you should switch
+#' to [label_ordinal()] for new code.
+#'
+#' @keywords internal
 #' @export
-#' @rdname label_ordinal
+#' @inheritParams label_ordinal
 ordinal_format <- label_ordinal
 
 #' @export
-#' @rdname label_ordinal
+#' @rdname ordinal_format
 ordinal <- function(x, prefix = "", suffix = "", big.mark = " ",
                     rules = ordinal_english(), ...) {
   na_idx <- is.na(x)
